==> jc-1.4.0.tar.gz: javax/swing/UIManager__24LookAndFeelInfo.h <==
// public class javax.swing.UIManager$LookAndFeelInfo

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 14423075d0b21178 javax_swing_UIManager__24LookAndFeelInfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_UIManager__24LookAndFeelInfo_H_
#define _JC_javax_swing_UIManager__24LookAndFeelInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_UIManager__24LookAndFeelInfo$sub_refs	_jc_javax_swing_UIManager__24LookAndFeelInfo$sub_refs;
typedef struct _jc_javax_swing_UIManager__24LookAndFeelInfo$sub_nonrefs	_jc_javax_swing_UIManager__24LookAndFeelInfo$sub_nonrefs;
typedef struct _jc_javax_swing_UIManager__24LookAndFeelInfo$refs	_jc_javax_swing_UIManager__24LookAndFeelInfo$refs;
typedef struct _jc_javax_swing_UIManager__24LookAndFeelInfo$nonrefs	_jc_javax_swing_UIManager__24LookAndFeelInfo$nonrefs;
typedef struct _jc_javax_swing_UIManager__24LookAndFeelInfo$object	_jc_javax_swing_UIManager__24LookAndFeelInfo$object;

typedef const struct _jc_javax_swing_UIManager__24LookAndFeelInfo$vmethods	_jc_javax_swing_UIManager__24LookAndFeelInfo$vmethods;
typedef const struct _jc_javax_swing_UIManager__24LookAndFeelInfo$vtable	_jc_javax_swing_UIManager__24LookAndFeelInfo$vtable;
typedef const struct _jc_javax_swing_UIManager__24LookAndFeelInfo$vtype	_jc_javax_swing_UIManager__24LookAndFeelInfo$vtype;

// Constructors
extern void _jc_javax_swing_UIManager__24LookAndFeelInfo$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_swing_UIManager__24LookAndFeelInfo$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_swing_UIManager__24LookAndFeelInfo$method$getClassName$333433582f896913(_jc_env *, struct _jc_javax_swing_UIManager__24LookAndFeelInfo$object *);
extern struct _jc_java_lang_String$object *_jc_javax_swing_UIManager__24LookAndFeelInfo$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_swing_UIManager__24LookAndFeelInfo$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_UIManager__24LookAndFeelInfo$method_info$getClassName$333433582f896913;
extern _jc_method _jc_javax_swing_UIManager__24LookAndFeelInfo$method_info$getName$bec186f2ce7e1882;

// Virtual methods structure
struct _jc_javax_swing_UIManager__24LookAndFeelInfo$vmethods {
	struct _jc_java_lang_String$object	*(*getClassName$333433582f896913)(_jc_env *, struct _jc_javax_swing_UIManager__24LookAndFeelInfo$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_swing_UIManager__24LookAndFeelInfo$object *);
};

// Vtable
struct _jc_javax_swing_UIManager__24LookAndFeelInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_UIManager__24LookAndFeelInfo$vmethods	javax_swing_UIManager__24LookAndFeelInfo;
};

// Vtype
struct _jc_javax_swing_UIManager__24LookAndFeelInfo$vtype {
	_jc_type			type;
	_jc_javax_swing_UIManager__24LookAndFeelInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_UIManager__24LookAndFeelInfo$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*clazz;
};

// Reference instance fields (object)
struct _jc_javax_swing_UIManager__24LookAndFeelInfo$refs {
    _jc_javax_swing_UIManager__24LookAndFeelInfo$sub_refs	javax_swing_UIManager__24LookAndFeelInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_UIManager__24LookAndFeelInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_UIManager__24LookAndFeelInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_UIManager__24LookAndFeelInfo$sub_nonrefs	javax_swing_UIManager__24LookAndFeelInfo;
};

// Object instance structure
struct _jc_javax_swing_UIManager__24LookAndFeelInfo$object {
	_jc_javax_swing_UIManager__24LookAndFeelInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_UIManager__24LookAndFeelInfo$vtype	*vtype;
	_jc_javax_swing_UIManager__24LookAndFeelInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_UIManager__24LookAndFeelInfo$vtype _jc_javax_swing_UIManager__24LookAndFeelInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_UIManager__24LookAndFeelInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_UIManager__24LookAndFeelInfo$class_object;

#endif	/* _JC_javax_swing_UIManager__24LookAndFeelInfo_H_ */

==> jc-1.4.5.tar.gz: javax/swing/UIManager__24LookAndFeelInfo.h <==
// public class javax.swing.UIManager$LookAndFeelInfo

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 14423075d0b21178 javax_swing_UIManager__24LookAndFeelInfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_UIManager__24LookAndFeelInfo_H_
#define _JC_javax_swing_UIManager__24LookAndFeelInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_UIManager__24LookAndFeelInfo$sub_refs	_jc_javax_swing_UIManager__24LookAndFeelInfo$sub_refs;
typedef struct _jc_javax_swing_UIManager__24LookAndFeelInfo$sub_nonrefs	_jc_javax_swing_UIManager__24LookAndFeelInfo$sub_nonrefs;
typedef struct _jc_javax_swing_UIManager__24LookAndFeelInfo$refs	_jc_javax_swing_UIManager__24LookAndFeelInfo$refs;
typedef struct _jc_javax_swing_UIManager__24LookAndFeelInfo$nonrefs	_jc_javax_swing_UIManager__24LookAndFeelInfo$nonrefs;
typedef struct _jc_javax_swing_UIManager__24LookAndFeelInfo$object	_jc_javax_swing_UIManager__24LookAndFeelInfo$object;

typedef const struct _jc_javax_swing_UIManager__24LookAndFeelInfo$vmethods	_jc_javax_swing_UIManager__24LookAndFeelInfo$vmethods;
typedef const struct _jc_javax_swing_UIManager__24LookAndFeelInfo$vtable	_jc_javax_swing_UIManager__24LookAndFeelInfo$vtable;
typedef const struct _jc_javax_swing_UIManager__24LookAndFeelInfo$vtype	_jc_javax_swing_UIManager__24LookAndFeelInfo$vtype;

// Constructors
extern void _jc_javax_swing_UIManager__24LookAndFeelInfo$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_swing_UIManager__24LookAndFeelInfo$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_swing_UIManager__24LookAndFeelInfo$method$getClassName$333433582f896913(_jc_env *, struct _jc_javax_swing_UIManager__24LookAndFeelInfo$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_UIManager__24LookAndFeelInfo$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_swing_UIManager__24LookAndFeelInfo$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_UIManager__24LookAndFeelInfo$method_info$getClassName$333433582f896913;
extern _jc_method _jc_javax_swing_UIManager__24LookAndFeelInfo$method_info$getName$bec186f2ce7e1882;

// Virtual methods structure
struct _jc_javax_swing_UIManager__24LookAndFeelInfo$vmethods {
	struct _jc_java_lang_String$object	*(*getClassName$333433582f896913)(_jc_env *, struct _jc_javax_swing_UIManager__24LookAndFeelInfo$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_swing_UIManager__24LookAndFeelInfo$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_UIManager__24LookAndFeelInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_UIManager__24LookAndFeelInfo$vmethods	javax_swing_UIManager__24LookAndFeelInfo;
};

// Vtype
struct _jc_javax_swing_UIManager__24LookAndFeelInfo$vtype {
	_jc_type			type;
	_jc_javax_swing_UIManager__24LookAndFeelInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_UIManager__24LookAndFeelInfo$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*clazz;
};

// Reference instance fields (object)
struct _jc_javax_swing_UIManager__24LookAndFeelInfo$refs {
    _jc_javax_swing_UIManager__24LookAndFeelInfo$sub_refs	javax_swing_UIManager__24LookAndFeelInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_UIManager__24LookAndFeelInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_UIManager__24LookAndFeelInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_UIManager__24LookAndFeelInfo$sub_nonrefs	javax_swing_UIManager__24LookAndFeelInfo;
};

// Object instance structure
struct _jc_javax_swing_UIManager__24LookAndFeelInfo$object {
	_jc_javax_swing_UIManager__24LookAndFeelInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_UIManager__24LookAndFeelInfo$vtype	*vtype;
	_jc_javax_swing_UIManager__24LookAndFeelInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_UIManager__24LookAndFeelInfo$vtype _jc_javax_swing_UIManager__24LookAndFeelInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_UIManager__24LookAndFeelInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_UIManager__24LookAndFeelInfo$class_object;

#endif	/* _JC_javax_swing_UIManager__24LookAndFeelInfo_H_ */
